.. _about:


.. raw:: html

    <br>

.. title:: About


.. raw:: html

    <center>

about
#####

.. raw:: html

    </center>
    <br>


In 2018 in informed the First Chamber of the Netherlands that antipsychotics
are proven to be poison. The greffe of the chamber confirmed the receiving
of the letter.

